==> v1.24.4-beta.zip: dominion/src/main/java/cn/lunadeer/dominion/commands/DominionFlag.java <==
package cn.lunadeer.dominion.commands;

import cn.lunadeer.dominion.Dominion;
import cn.lunadeer.dominion.controllers.FlagsController;
import cn.lunadeer.dominion.tuis.DominionFlagInfo;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;

import static cn.lunadeer.dominion.commands.Apis.playerOnly;

public class DominionFlag {

    /**
     * 设置领地权限
     * /dominion set <权限名称> <true/false> [领地名称]
     *
     * @param sender 命令发送者
     * @param args   命令参数
     */
    public static void setDominionFlag(CommandSender sender, String[] args) {
        Player player = playerOnly(sender);
        if (player == null) return;
        if (args.length == 3) {
            if (FlagsController.setFlag(player, args[1], Boolean.parseBoolean(args[2])) == null) {
                Dominion.notification.error(sender, "设置领地权限失败");
            }
        } else if (args.length == 4) {
            if (FlagsController.setFlag(player, args[1], Boolean.parseBoolean(args[2]), args[3]) == null) {
                Dominion.notification.error(sender, "设置领地权限失败");
            }
        } else if (args.length == 5) {
            if (FlagsController.setFlag(player, args[1], Boolean.parseBoolean(args[2]), args[3]) == null) {
                Dominion.notification.error(sender, "设置领地权限失败");
            }
            String[] newArgs = new String[3];
            newArgs[0] = "flag_info";
            newArgs[1] = args[3];
            newArgs[2] = args[4];
            DominionFlagInfo.show(sender, newArgs);
            return;
        } else {
            Dominion.notification.error(sender, "用法: /dominion set <权限名称> <true/false> [领地名称]");
            return;
        }
        Dominion.notification.info(sender, "设置领地权限 %s 为 %s", args[1], args[2]);
    }

}

==> v1.30.6-beta.zip: dominion/src/main/java/cn/lunadeer/dominion/commands/DominionFlag.java <==
package cn.lunadeer.dominion.commands;

import cn.lunadeer.dominion.controllers.BukkitPlayerOperator;
import cn.lunadeer.dominion.controllers.FlagsController;
import cn.lunadeer.dominion.tuis.DominionFlagInfo;
import cn.lunadeer.minecraftpluginutils.Notification;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;

import static cn.lunadeer.dominion.commands.Apis.playerOnly;

public class DominionFlag {

    /**
     * 设置领地权限
     * /dominion set <权限名称> <true/false> [领地名称]
     *
     * @param sender 命令发送者
     * @param args   命令参数
     */
    public static void setDominionFlag(CommandSender sender, String[] args) {
        Player player = playerOnly(sender);
        if (player == null) return;
        BukkitPlayerOperator operator = BukkitPlayerOperator.create(player);
        if (args.length == 3) {
            FlagsController.setFlag(operator, args[1], Boolean.parseBoolean(args[2]));
        } else if (args.length == 4) {
            FlagsController.setFlag(operator, args[1], Boolean.parseBoolean(args[2]), args[3]);
        } else if (args.length == 5) {
            FlagsController.setFlag(operator, args[1], Boolean.parseBoolean(args[2]), args[3]);
            String[] newArgs = new String[3];
            newArgs[0] = "flag_info";
            newArgs[1] = args[3];
            newArgs[2] = args[4];
            DominionFlagInfo.show(sender, newArgs);
        } else {
            Notification.error(sender, "用法: /dominion set <权限名称> <true/false> [领地名称]");
        }
    }

}
